@@ -4,6 +4,8 @@ use thiserror::Error;
 pub enum Error {
     #[error("general io error: {0}")]
     Io(#[from] std::io::Error),
+    #[error("parse int error: {0}")]
+    Int(#[from] std::num::ParseIntError),
     #[error("env error: {0}")]
     Env(#[from] dotenv::Error),
     #[error("uri error: {0}")]
