@@ -2,6 +2,9 @@ use crate::{error::Error, Result};
 use serde::{Deserialize, Serialize};
 use std::collections::HashMap;
 
+#[cfg(feature = "disk-cache")]
+use surf_middleware_cache::{managers::CACacheManager, Cache, CacheMode};
+
 #[derive(Clone, Debug, Serialize, Deserialize)]
 pub struct JWK {
     pub kty: String,
@@ -29,9 +32,30 @@ impl JWKS {
     }
 }
 
+#[cfg(feature = "disk-cache")]
+fn build_client() -> surf::Client {
+    surf::Client::new().with(Cache {
+        mode: CacheMode::Default,
+        cache_manager: CACacheManager::default(),
+    })
+}
+
+#[cfg(not(feature = "disk-cache"))]
+fn build_client() -> surf::Client {
+    surf::Client::new()
+}
+
 pub async fn get(issuer: &str) -> Result<JWKS> {
     let url = format!("{}/v1/keys", &issuer);
-    let KeyResponse { keys } = match surf::get(&url).recv_json().await {
+    let req = surf::get(&url);
+    let client = build_client();
+    let mut res = match client.send(req).await {
+        Ok(r) => r,
+        Err(e) => {
+            return Err(Error::Other(e.into_inner()));
+        }
+    };
+    let KeyResponse { keys } = match res.body_json().await {
         Ok(k) => k,
         Err(e) => {
             return Err(Error::Other(e.into_inner()));
